@@ -5,9 +5,11 @@ from typing import (
     Iterator,
     Any,
     List,
+    AsyncGenerator,
 )
 
 ReplyDict = Dict[str, Any]
 ResponseIter = Iterator[ReplyDict]
+AsyncResponseIter = AsyncGenerator[ReplyDict, None]
 QueryGen = Iterator[str]
 Response = List[Dict[str, Any]]
